==> nextcloud-16.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/twofactor_backupcodes/l10n/pl.js <==
OC.L10N.register(
    "twofactor_backupcodes",
    {
    "_" : "_",
    "An error occurred while generating your backup codes" : "Wystąpił błąd podczas generowania kodów zapasowych.",
    "{name} backup codes" : "Kody kopii zapasowej {name}",
    "These are your backup codes. Please save and/or print them as you will not be able to read the codes again later" : "To są kody zapasowe. Proszę je zapisać i/lub wydrukować, ponieważ później nie będzie można ich ponownie odczytać",
    "Save backup codes" : "Zapisz kody zapasowe",
    "Print backup codes" : "Drukuj kody zapasowe",
    "Backup codes have been generated. {used} of {total} codes have been used." : "Wygenerowano kody zapasowe. Użyto {used} z {total} kodów.",
    "Regenerate backup codes" : "Ponownie generuj kody zapasowe",
    "_icon-loading-small_::_generate-backup-codes_" : ["mała ikona ładowania","małe ikony ładowania","małe ikony ładowania","generuj kody zapasowe"],
    "If you regenerate backup codes, you automatically invalidate old codes." : "Jeśli generujesz kody zapasowe ponownie, automatycznie unieważniasz stare kody.",
    "Generate backup codes" : "Generowanie kodów zapasowych",
    "You created two-factor backup codes for your account" : "Stworzyłeś zapasowe kody uwierzytelnienia dwuskładnikowego swojego konta",
    "Second-factor backup codes" : "Kody zapasowe uwierzytelnienia dwuskładnikowego",
    "You enabled two-factor authentication but did not generate backup codes yet. They are needed to restore access to your account in case you lose your second factor." : "Włączyłeś uwierzytelnianie dwuskładnikowe, ale nie wygenerowłeś jeszcze kodów zapasowych. Są one potrzebne do przywrócenia dostępu do Twojego konta w przypadku utraty drugiego składnika.",
    "Backup code" : "Kody zapasowe",
    "Use backup code" : "Użyj kodu zapasowego",
    "Two factor backup codes" : "Kody zapasowe uwierzytelnienia dwuskładnikowego",
    "A two-factor auth backup codes provider" : "Dostawca dwuskładnikowych kodów zapasowych ",
    "Use one of the backup codes you saved when setting up two-factor authentication." : "Użyj jednego z kodów zapasowych zapisanych podczas konfigurowania uwierzytelniania dwuskładnikowego.",
    "Submit" : "Prześlij",
    "Backup codes have been generated. {{used}} of {{total}} codes have been used." : "Kody zapasowe zostały wygenerowane. {{used}} z {{total}} kodów zostało wykorzystanych.",
    "Nextcloud backup codes" : "Kody zapasowe Nextcloud",
    "activated" : "aktowowane",
    "updated" : "zaktualizowane",
    "mounted" : "zamontowane",
    "deactivated" : "zdezaktywowane",
    "beforeCreate" : "przed utworzeniem",
    "created" : "utworzone",
    "beforeUpdate" : "przed aktualizacją",
    "beforeDestroy" : "przed zniszczeniem",
    "destroyed" : "zniszczone",
    "beforeMount" : "przed zamontowaniem",
    "You have enabled two-factor authentication but have not yet generated backup codes. Be sure to do this in case you lose access to your second factor." : "Włączyłeś uwierzytelnianie dwuskładnikowe, ale jeszcze nie wygenerowałeś kodów zapasowych. Pamiętaj, aby to zrobić na wypadek utraty dostępu do drugiego składnika."
},
"nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");

==> nextcloud-17.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/twofactor_backupcodes/l10n/pl.js <==
OC.L10N.register(
    "twofactor_backupcodes",
    {
    "function" : "funkcja",
    "_" : "_",
    "An error occurred while generating your backup codes" : "Wystąpił błąd podczas generowania kodów zapasowych.",
    "{name} backup codes" : "Kody kopii zapasowej {name}",
    "These are your backup codes. Please save and/or print them as you will not be able to read the codes again later" : "To są kody zapasowe. Proszę je zapisać i/lub wydrukować, ponieważ później nie będzie można ich ponownie odczytać",
    "Save backup codes" : "Zapisz kody zapasowe",
    "Print backup codes" : "Drukuj kody zapasowe",
    "Backup codes have been generated. {used} of {total} codes have been used." : "Wygenerowano kody zapasowe. Użyto {used} z {total} kodów.",
    "Regenerate backup codes" : "Ponownie generuj kody zapasowe",
    "_icon-loading-small_::_generate-backup-codes_" : ["mała ikona ładowania","małe ikony ładowania","małe ikony ładowania","generuj kody zapasowe"],
    "If you regenerate backup codes, you automatically invalidate old codes." : "Jeśli generujesz kody zapasowe ponownie, automatycznie unieważniasz stare kody.",
    "Generate backup codes" : "Generowanie kodów zapasowych",
    "You created two-factor backup codes for your account" : "Stworzyłeś zapasowe kody uwierzytelnienia dwuskładnikowego swojego konta",
    "Second-factor backup codes" : "Kody zapasowe uwierzytelnienia dwuskładnikowego",
    "You enabled two-factor authentication but did not generate backup codes yet. They are needed to restore access to your account in case you lose your second factor." : "Włączyłeś uwierzytelnianie dwuskładnikowe, ale nie wygenerowłeś jeszcze kodów zapasowych. Są one potrzebne do przywrócenia dostępu do Twojego konta w przypadku utraty drugiego składnika.",
    "Backup code" : "Kody zapasowe",
    "Use backup code" : "Użyj kodu zapasowego",
    "Two factor backup codes" : "Kody zapasowe uwierzytelnienia dwuskładnikowego",
    "A two-factor auth backup codes provider" : "Dostawca dwuskładnikowych kodów zapasowych ",
    "Use one of the backup codes you saved when setting up two-factor authentication." : "Użyj jednego z kodów zapasowych zapisanych podczas konfigurowania uwierzytelniania dwuskładnikowego.",
    "Submit" : "Prześlij",
    "activated" : "aktowowane",
    "updated" : "zaktualizowane",
    "mounted" : "zamontowane",
    "deactivated" : "zdezaktywowane",
    "beforeCreate" : "przed utworzeniem",
    "created" : "utworzone",
    "beforeUpdate" : "przed aktualizacją",
    "beforeDestroy" : "przed zniszczeniem",
    "destroyed" : "zniszczone",
    "beforeMount" : "przed zamontowaniem",
    "Nextcloud backup codes" : "Kody zapasowe Nextcloud",
    "You have enabled two-factor authentication but have not yet generated backup codes. Be sure to do this in case you lose access to your second factor." : "Włączyłeś uwierzytelnianie dwuskładnikowe, ale jeszcze nie wygenerowałeś kodów zapasowych. Pamiętaj, aby to zrobić na wypadek utraty dostępu do drugiego składnika."
},
"nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");
